//[mahjong-utils](../../../index.md)/[mahjongutils.shanten](../index.md)/[Improvement](index.md)/[advance](advance.md)

# advance

[common]\
val [advance](advance.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;

摸上改良张且弃牌后的进张
